# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-parent
Epoch:		1
Version:	0.244
Release:	1.%{__distinit}%{__distvers}
Summary:	Establish an ISA relationship with base classes at compile time
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/parent
Source0:	https://cpan.metacpan.org/authors/id/C/CO/CORION/parent-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(strict)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More) >= 0.40
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Allows you to both load one or more modules, while setting up inheritance
from those modules at the same time. Mostly similar in effect to:

	package Baz;

	BEGIN {
		require Foo;
		require Bar;

		push @ISA, qw(Foo Bar);
	}

%prep
%setup -q -n parent-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes
%{perl_vendorlib}/parent.pm
%{_mandir}/man3/parent.3*

%changelog
* Fri Dec 13 2024 Paul Howarth <paul@city-fan.org> - 1:0.244-1
- Update to 0.244
  - Update (commented) comparison with $] to use quotes

* Fri Nov 29 2024 Paul Howarth <paul@city-fan.org> - 1:0.243-1
- Update to 0.243
  - Reinstate test for apostrophe as package separator, as that package
    separator is allowed again (no code change, only tests have been amended)

* Wed Aug 14 2024 Paul Howarth <paul@city-fan.org> - 1:0.242-1
- Update to 0.242
  - Don't test for apostrophe as package separator on Perl versions after 5.41
  - Protect against modules changing @_

* Wed Feb 15 2023 Paul Howarth <paul@city-fan.org> - 1:0.241-1
- Update to 0.241
  - Actually include the changes documented for version 0.240

* Tue Feb 14 2023 Paul Howarth <paul@city-fan.org> - 1:0.240-1
- Update to 0.240
  - Use Test::More::isnt() instead of Test::More::isn't in tests, which is
    deprecated, as ' isn't allowed as package separator in an upcoming version
    of Perl (GH#13)

* Wed Dec  7 2022 Paul Howarth <paul@city-fan.org> - 1:0.239-1
- Update to 0.239
  - Harden against changes to require error messages: the '@INC contains' may
    change in a future release of perl; this hardens the test to be insensitive
    to the exact words chosen (https://github.com/Perl/perl5/pull/20547)
- Use SPDX-format license tag

* Fri Feb  7 2020 Paul Howarth <paul@city-fan.org> - 1:0.238-1
- Update to 0.238
  - Move the prerequisite Test::More from being a runtime prerequisite to a
    test time / build time prerequisite (GH#11)

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 1:0.237-438
- Perl 5.30 rebuild

* Sat Jul  7 2018 Paul Howarth <paul@city-fan.org> - 1:0.237-1
- Update to 0.237
  - Don't load vars.pm (Perl RT#132077)

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1:0.236-416
- Perl 5.28 rebuild

* Thu Apr 19 2018 Paul Howarth <paul@city-fan.org> - 1:0.236-395
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Mon Oct 10 2016 Paul Howarth <paul@city-fan.org> - 1:0.236-1
- Update to 0.236
  - Add Travis test configuration
  - Make test for PMC availability more reliable
  - Disable benchmark test rt62341.t as it runs out of memory on many smoker
    systems (CPAN RT#118310)

* Fri Sep 16 2016 Paul Howarth <paul@city-fan.org> - 1:0.234-365
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 1:0.234-2
- Perl 5.22 rebuild

* Thu May 28 2015 Paul Howarth <paul@city-fan.org> - 1:0.234-1
- Update to 0.234
  - Fix the test for PMC loading to work on versions of Perl that don't have
    Config::non_bincompat_options (CPAN RT#102626)

* Tue May 26 2015 Paul Howarth <paul@city-fan.org> - 1:0.233-1
- Update to 0.233
  - The diagnostic about inheriting from ourselves was removed; it served no
    purpose as Perl already warns if we try to inherit in a circular way

* Fri Mar 20 2015 Paul Howarth <paul@city-fan.org> - 1:0.232-1
- Update to 0.232
  - Change line-endings in parent-pmc.t to unix EOLs so that bleadperl is happy

* Tue Mar 10 2015 Paul Howarth <paul@city-fan.org> - 1:0.231-1
- Update to 0.231
  - Restore test compatibility where Perl does not provide
    &Config::non_bincompat_options (CPAN RT#102626)

* Sat Mar  7 2015 Paul Howarth <paul@city-fan.org> - 1:0.229-1
- Update to 0.229
  - Add link to (Github) repository
  - Guard tests against PERL_DISABLE_PMC
- Revert use of Config::non_bincompat_options for Perl < 5.13.10
  (CPAN RT#101162)
- Classify buildreqs by usage

* Wed Sep  3 2014 Paul Howarth <paul@city-fan.org> - 1:0.228-310
- Drop %%defattr, redundant since rpm 4.4

* Tue Sep 17 2013 Paul Howarth <paul@city-fan.org> - 1:0.228-1
- Update to 0.228
  - Install in site/ by default for 5.12+ (CPAN RT#88450)

* Sun Sep  1 2013 Paul Howarth <paul@city-fan.org> - 1:0.227-1
- Update to 0.227
  - Restore tests passing for 5.17.5+ (CPAN RT#88320)

* Mon Jul 29 2013 Paul Howarth <paul@city-fan.org> - 1:0.226-1
- Update to 0.226
  - Fix tests for Perl 5.18 (CPAN RT#86890)

* Mon Jul 15 2013 Paul Howarth <paul@city-fan.org> - 1:0.225-290
- Adjust tests to perl-5.18 (CPAN RT#86890)

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 1:0.225-7
- BR: perl(lib)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Feb  7 2012 Paul Howarth <paul@city-fan.org> - 1:0.225-6
- Install to vendor directories rather than perl core directories so as to
  avoid conflicts between our debuginfo and the main perl-debuginfo package

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 1:0.225-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Mar  8 2011 Paul Howarth <paul@city-fan.org> - 1:0.225-1
- Update to 0.225
  - fix the documentation about the warning of inheriting from yourself
    (CPAN RT#66459)

* Mon Nov 22 2010 Paul Howarth <paul@city-fan.org> - 1:0.224-2
- Import from Fedora
- Don't package tests, which would need extensive provides filtering
- Install in vendor perl directory for perl < 5.10.1

* Sun Nov 21 2010 Iain Arnell <iarnell@gmail.com> - 1:0.224-1
- Update to latest upstream version

* Tue May 04 2010 Marcela Maslanova <mmaslano@redhat.com> - 1:0.223-4
- Mass rebuild with perl-5.12.0

* Sat Mar 27 2010 Iain Arnell <iarnell@gmail.com> - 1:0.223-3
- Dual-life module
- Add epoch to match that of parent in core
- Use core macros, not vendor

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.223-2
- Rebuild against perl 5.10.1

* Fri Sep 11 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.223-1
- Update filtering
- Auto-update to 0.223 (by cpan-spec-update 0.01)
- Altered br on perl(Test::More) (0 => 0.4)

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.221-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.221-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jun 19 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.221-2
- Bump

* Wed May 28 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.221-1
- Specfile autogenerated by cpanspec 1.75
